@@ -7,7 +7,7 @@ del get_versions
 
 import os
 import matplotlib
-import opencv
+import cv2
 from LivestockCV.core.show_image import show_image
 from LivestockCV.core.dimensions import dimensions
 
